# -*- coding: utf8 -*-

# Création des logins INP-net.

from .models import Inscription
from ldap_inp import LdapEleve

import re
import unidecode


LOGINS_RESERVES = (
    "root",
    "daemon",
    "bin",
    "sys",
    "sync",
    "games",
    "man",
    "lp",
    "mail",
    "news",
    "uucp",
    "proxy",
    "postgres",
    "www-data",
    "backup",
    "operator",
    "list",
    "irc",
    "tina",
    "gnats",
    "nobody",
    "mysql",
    "identd",
    "sshd",
    "alias",
    "qmaild",
    "qmails",
    "qmailr",
    "qmailq",
    "qmaill",
    "qmailp",
    "install",
    "sympa",
    "portail",
    "pipobot",
)


def login_utilise(login):
    return (
        (login in LOGINS_RESERVES)
        or (len(LdapEleve.objects.filter(uid=login)) != 0)
        or (Inscription.objects.filter(login=login).count() != 0)
    )


def vers_alphabet(mot, garder_ponct=False):
    assert isinstance(mot, str)

    mot = unidecode.unidecode(mot).strip().lower()
    if garder_ponct:
        return mot
    else:
        return re.sub("[^a-z]", "", mot)


def genere_login(nom, prenom):
    nom_simp = vers_alphabet(nom)
    prenom_simp = vers_alphabet(prenom)

    if len(nom_simp) == 0 or len(prenom_simp) == 0:
        return None

    debut_login = nom_simp[0:6]

    # 1) Premières lettres du nom et première lettre du prénom
    login = debut_login + prenom_simp[0]
    if not login_utilise(login):
        return login

    # 2) Premières lettres du nom et deux premières lettres du prénom
    login = debut_login + prenom_simp[0:2]
    if not login_utilise(login):
        return login

    # 4) Si le nom 8 caractères ou moins, on essaye nom et début prénom
    if len(nom_simp) <= 8:
        temp = nom_simp + prenom_simp

        for i in range(len(nom_simp), 8):
            login = temp[0:i]
            if not login_utilise(login):
                return login

    # 5) Premières lettres du nom, première lettre du prénom et chiffre
    for i in range(2, 9):
        login = debut_login + prenom_simp[0] + str(i)
        if not login_utilise(login):
            return login

    # 6) Premières lettres du nom et chiffres
    for i in range(2, 99):
        login = debut_login + str(i)
        if not login_utilise(login):
            return login

    # Panique !
    return None
